@@ -3,16 +3,18 @@ package Geo::Coder::Many;
 use strict;
 use warnings;
 use Carp;
-use Time::HiRes;
-use Sort::Versions;
 use List::MoreUtils qw(any);
+use Sort::Versions;
+use Time::HiRes;
 
-our $VERSION = 0.45;
+our $VERSION = 0.46;
 
+# note - also update lists far below in pod
 use Geo::Coder::Many::Bing;
 use Geo::Coder::Many::Google;
 use Geo::Coder::Many::Googlev3;
 use Geo::Coder::Many::Mapquest;
+use Geo::Coder::Many::OpenCage;
 use Geo::Coder::Many::OSM;
 use Geo::Coder::Many::Ovi;
 use Geo::Coder::Many::PlaceFinder;
@@ -855,7 +857,7 @@ Currently supported Geo::Coder::* modules are:
   Geo::Coder::Google
   Geo::Coder::Googlev3
   Geo::Coder::Mapquest
-  Geo::Coder::Multimap
+  Geo::Coder::OpenCage
   Geo::Coder::OSM
   Geo::Coder::Ovi
   Geo::Coder::PlaceFinder
@@ -866,7 +868,7 @@ Currently supported Geo::Coder::* modules are:
   Geo::Coder::Google
   Geo::Coder::Googlev3
   Geo::Coder::Mapquest
-  Geo::Coder::Multimap
+  Geo::Coder::OpenCage
   Geo::Coder::OSM
   Geo::Coder::Ovi
   Geo::Coder::PlaceFinder
@@ -889,7 +891,7 @@ http://search.cpan.org/~friffin/
 
 =head1 FEEDBACK
 
-Patches are encouraged! Please send any code (ideally with tests) or
+Patches are encouraged! Please fork on github (ideally with tests) or send
 feedback to cpan@lokku.com
 
 =head1 ACKNOWLEDGEMENTS
@@ -904,12 +906,17 @@ any deficiencies in the implementation!
 =head1 YOU MAY ALSO ENJOY
 
 If reducing your dependancy on geo information providers is your thing - and 
-really, who doesn't enjoy breaking dependancy? - you'll
-probably like Mapstraction - http://mapstraction.com
+really, who doesn't enjoy breaking dependancy? - then you will probably like 
+Mapstraction - http://mapstraction.com
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2011,2012 Lokku Ltd <cpan@lokku.com>
+Copyright 2014 Lokku Ltd <cpan@lokku.com>
+
+Please check out all our open source work over at https://github.com/lokku and 
+our developer blog: http://devblog.nestoria.com
+
+Thanks!
 
 Parts taken from Geo::Coder::Multiple are copyright 2009 Alistair Francis
 <opensource@alizta.com>
